# pngtools

## Usage

```bash
python -m pip install pngtools

python -m pngtools
```

## Python usage

```python
from pngtools import PNG_MAGIC, split_png_chunks
# do your things
```

## Development

```bash
python -m pip install -r requirements.txt

python -m pip install .
```

## License

- [MIT](LICENSE)